#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ILOG2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ILOG2_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/ilog2.hpp>

#endif
